@@ -10,11 +10,11 @@
   as published by the Free Software Foundation.
   
   ********************************************
-  Coppermine version: 1.4.23
+  Coppermine version: 1.4.24
   $HeadURL: https://coppermine.svn.sourceforge.net/svnroot/coppermine/trunk/cpg1.4.x/db_input.php $
-  $Revision: 5949 $
-  $Author: nibbler999 $
-  $Date: 2009-05-19 13:38:30 +0200 (Di, 19 Mai 2009) $
+  $Revision: 5969 $
+  $Author: gaugau $
+  $Date: 2009-05-21 22:03:33 +0200 (Do, 21 Mai 2009) $
 **********************************************/
 
 define('IN_COPPERMINE', true);
